def print_f(the_list,level=0):
	for each_item in the_list:
		if isinstance(each_item,list):
			print_f(each_item,level+1)
		else:
                        for each_level in range(level):
                                print("\t")
                        print(each_item)




from distutils.core import setup
setup(
name = 'MyNesterV2',
version = '2.5.0',
py_modules = ['MyNesterV2'],
author = 'kira02',
author_email = 'hfpython@headfirstlabs.com',
url = 'http://www.headfirstlabs.com',
description = 'A complex printer of nested lists',
)
